componenttools.split_components_once_by_prolated_durations_and_do_not_fracture_crossing_spanners
================================================================================================

.. autofunction:: abjad.tools.componenttools.split_components_once_by_prolated_durations_and_do_not_fracture_crossing_spanners.split_components_once_by_prolated_durations_and_do_not_fracture_crossing_spanners
